@@ -90,109 +90,113 @@ enum
   TERMINAL_PALETTE_N_BUILTINS
 };
 
+#define COLOR(r, g, b) { .red = (r) / 255.0, .green = (g) / 255.0, .blue = (b) / 255.0, .alpha = 1.0 }
+
 static const GdkRGBA terminal_palettes[TERMINAL_PALETTE_N_BUILTINS][TERMINAL_PALETTE_SIZE] =
 {
   /* Tango palette */
   {
-    { 0,         0,        0,         1 },
-    { 0.8,       0,        0,         1 },
-    { 0.305882,  0.603922, 0.0235294, 1 },
-    { 0.768627,  0.627451, 0,         1 },
-    { 0.203922,  0.396078, 0.643137,  1 },
-    { 0.458824,  0.313725, 0.482353,  1 },
-    { 0.0235294, 0.596078, 0.603922,  1 },
-    { 0.827451,  0.843137, 0.811765,  1 },
-    { 0.333333,  0.341176, 0.32549,   1 },
-    { 0.937255,  0.160784, 0.160784,  1 },
-    { 0.541176,  0.886275, 0.203922,  1 },
-    { 0.988235,  0.913725, 0.309804,  1 },
-    { 0.447059,  0.623529, 0.811765,  1 },
-    { 0.678431,  0.498039, 0.658824,  1 },
-    { 0.203922,  0.886275, 0.886275,  1 },
-    { 0.933333,  0.933333, 0.92549,   1 },
+    COLOR (0x00, 0x00, 0x00),
+    COLOR (0xcc, 0x00, 0x00),
+    COLOR (0x4e, 0x9a, 0x06),
+    COLOR (0xc4, 0xa0, 0x00),
+    COLOR (0x34, 0x65, 0xa4),
+    COLOR (0x75, 0x50, 0x7b),
+    COLOR (0x06, 0x98, 0x9a),
+    COLOR (0xd3, 0xd7, 0xcf),
+    COLOR (0x55, 0x57, 0x53),
+    COLOR (0xef, 0x29, 0x29),
+    COLOR (0x8a, 0xe2, 0x34),
+    COLOR (0xfc, 0xe9, 0x4f),
+    COLOR (0x72, 0x9f, 0xcf),
+    COLOR (0xad, 0x7f, 0xa8),
+    COLOR (0x34, 0xe2, 0xe2),
+    COLOR (0xee, 0xee, 0xec)
   },
 
   /* Linux palette */
   {
-    { 0,        0,        0,        1 },
-    { 0.666667, 0,        0,        1 },
-    { 0,        0.666667, 0,        1 },
-    { 0.666667, 0.333333, 0,        1 },
-    { 0,        0,        0.666667, 1 },
-    { 0.666667, 0,        0.666667, 1 },
-    { 0,        0.666667, 0.666667, 1 },
-    { 0.666667, 0.666667, 0.666667, 1 },
-    { 0.333333, 0.333333, 0.333333, 1 },
-    { 1,        0.333333, 0.333333, 1 },
-    { 0.333333, 1,        0.333333, 1 },
-    { 1,        1,        0.333333, 1 },
-    { 0.333333, 0.333333, 1,        1 },
-    { 1,        0.333333, 1,        1 },
-    { 0.333333, 1,        1,        1 },
-    { 1,        1,        1,        1 },
+    COLOR (0x00, 0x00, 0x00),
+    COLOR (0xaa, 0x00, 0x00),
+    COLOR (0x00, 0xaa, 0x00),
+    COLOR (0xaa, 0x55, 0x00),
+    COLOR (0x00, 0x00, 0xaa),
+    COLOR (0xaa, 0x00, 0xaa),
+    COLOR (0x00, 0xaa, 0xaa),
+    COLOR (0xaa, 0xaa, 0xaa),
+    COLOR (0x55, 0x55, 0x55),
+    COLOR (0xff, 0x55, 0x55),
+    COLOR (0x55, 0xff, 0x55),
+    COLOR (0xff, 0xff, 0x55),
+    COLOR (0x55, 0x55, 0xff),
+    COLOR (0xff, 0x55, 0xff),
+    COLOR (0x55, 0xff, 0xff),
+    COLOR (0xff, 0xff, 0xff)
   },
 
   /* XTerm palette */
   {
-    { 0,        0,        0,        1 },
-    { 0.803922, 0,        0,        1 },
-    { 0,        0.803922, 0,        1 },
-    { 0.803922, 0.803922, 0,        1 },
-    { 0.117647, 0.564706, 1,        1 },
-    { 0.803922, 0,        0.803922, 1 },
-    { 0,        0.803922, 0.803922, 1 },
-    { 0.898039, 0.898039, 0.898039, 1 },
-    { 0.298039, 0.298039, 0.298039, 1 },
-    { 1,        0,        0,        1 },
-    { 0,        1,        0,        1 },
-    { 1,        1,        0,        1 },
-    { 0.27451,  0.509804, 0.705882, 1 },
-    { 1,        0,        1,        1 },
-    { 0,        1,        1,        1 },
-    { 1,        1,        1,        1 },
+    COLOR (0x00, 0x00, 0x00),
+    COLOR (0xcd, 0x00, 0x00),
+    COLOR (0x00, 0xcd, 0x00),
+    COLOR (0xcd, 0xcd, 0x00),
+    COLOR (0x00, 0x00, 0xee),
+    COLOR (0xcd, 0x00, 0xcd),
+    COLOR (0x00, 0xcd, 0xcd),
+    COLOR (0xe5, 0xe5, 0xe5),
+    COLOR (0x7f, 0x7f, 0x7f),
+    COLOR (0xff, 0x00, 0x00),
+    COLOR (0x00, 0xff, 0x00),
+    COLOR (0xff, 0xff, 0x00),
+    COLOR (0x5c, 0x5c, 0xff),
+    COLOR (0xff, 0x00, 0xff),
+    COLOR (0x00, 0xff, 0xff),
+    COLOR (0xff, 0xff, 0xff)
   },
 
   /* RXVT palette */
   {
-    { 0,        0,        0,        1 },
-    { 0.803922, 0,        0,        1 },
-    { 0,        0.803922, 0,        1 },
-    { 0.803922, 0.803922, 0,        1 },
-    { 0,        0,        0.803922, 1 },
-    { 0.803922, 0,        0.803922, 1 },
-    { 0,        0.803922, 0.803922, 1 },
-    { 0.980392, 0.921569, 0.843137, 1 },
-    { 0.25098,  0.25098,  0.25098,  1 },
-    { 1, 0, 0, 1 },
-    { 0, 1, 0, 1 },
-    { 1, 1, 0, 1 },
-    { 0, 0, 1, 1 },
-    { 1, 0, 1, 1 },
-    { 0, 1, 1, 1 },
-    { 1, 1, 1, 1 },
+    COLOR (0x00, 0x00, 0x00),
+    COLOR (0xcd, 0x00, 0x00),
+    COLOR (0x00, 0xcd, 0x00),
+    COLOR (0xcd, 0xcd, 0x00),
+    COLOR (0x00, 0x00, 0xcd),
+    COLOR (0xcd, 0x00, 0xcd),
+    COLOR (0x00, 0xcd, 0xcd),
+    COLOR (0xfa, 0xeb, 0xd7),
+    COLOR (0x40, 0x40, 0x40),
+    COLOR (0xff, 0x00, 0x00),
+    COLOR (0x00, 0xff, 0x00),
+    COLOR (0xff, 0xff, 0x00),
+    COLOR (0x00, 0x00, 0xff),
+    COLOR (0xff, 0x00, 0xff),
+    COLOR (0x00, 0xff, 0xff),
+    COLOR (0xff, 0xff, 0xff)
   },
 
   /* Solarized palette (1.0.0beta2): http://ethanschoonover.com/solarized */
   {
-    { 0.02745,  0.211764, 0.258823, 1 },
-    { 0.862745, 0.196078, 0.184313, 1 },
-    { 0.521568, 0.6,      0,        1 },
-    { 0.709803, 0.537254, 0,        1 },
-    { 0.149019, 0.545098, 0.823529, 1 },
-    { 0.82745,  0.211764, 0.509803, 1 },
-    { 0.164705, 0.631372, 0.596078, 1 },
-    { 0.933333, 0.909803, 0.835294, 1 },
-    { 0,        0.168627, 0.211764, 1 },
-    { 0.796078, 0.294117, 0.086274, 1 },
-    { 0.345098, 0.431372, 0.458823, 1 },
-    { 0.396078, 0.482352, 0.513725, 1 },
-    { 0.513725, 0.580392, 0.588235, 1 },
-    { 0.423529, 0.443137, 0.768627, 1 },
-    { 0.57647,  0.631372, 0.631372, 1 },
-    { 0.992156, 0.964705, 0.890196, 1 },
+    COLOR (0x07, 0x36, 0x42),
+    COLOR (0xdc, 0x32, 0x2f),
+    COLOR (0x85, 0x99, 0x00),
+    COLOR (0xb5, 0x89, 0x00),
+    COLOR (0x26, 0x8b, 0xd2),
+    COLOR (0xd3, 0x36, 0x82),
+    COLOR (0x2a, 0xa1, 0x98),
+    COLOR (0xee, 0xe8, 0xd5),
+    COLOR (0x00, 0x2b, 0x36),
+    COLOR (0xcb, 0x4b, 0x16),
+    COLOR (0x58, 0x6e, 0x75),
+    COLOR (0x65, 0x7b, 0x83),
+    COLOR (0x83, 0x94, 0x96),
+    COLOR (0x6c, 0x71, 0xc4),
+    COLOR (0x93, 0xa1, 0xa1),
+    COLOR (0xfd, 0xf6, 0xe3)
   },
 };
 
+#undef COLOR
+
 static void profile_colors_notify_scheme_combo_cb (GSettings *profile,
                                                    const char *key,
                                                    GtkComboBox *combo);
